import json
from functools import partial
from typing import Final

__all__ = ('json_dumps', 'get_python_version', 'get_software', 'debug')

json_dumps: Final = partial(json.dumps, ensure_ascii=False)


def get_python_version() -> str:
    from sys import version_info as version
    return f'{version.major}.{version.minor}.{version.micro}'


def get_software() -> str:
    from . import __version__
    return f'Python/{get_python_version()} aioairtable/{__version__}'


def debug() -> bool:
    return __debug__



__version__ = '0.0.15'

from .aioairtable import (DT_FORMAT, Airtable, AirtableBase, AirtableRecord,
                          AirtableTable, Attachment, CellFormat, Collaborator,
                          Fields, Method, RequestAttachment, SortDirection,
                          Thumbnail)

__all__ = ('__version__', 'DT_FORMAT', 'Method', 'Fields', 'Thumbnail',
           'Attachment', 'RequestAttachment', 'Collaborator', 'SortDirection',
           'CellFormat', 'Airtable', 'AirtableBase', 'AirtableTable',
           'AirtableRecord')
